package com.mirrorworlds.topsight.mail.tnef;

import com.mirrorworlds.topsight.core.MimeTypeMap;
/**
 * implementation for the tnef content-type map based on Topsight's MimeTypeMap.
 *
 * @author      Priyantha Jayanetti
 * @version     Feb 20, 2000 Lifestreams 1.4 xerox
 *
 */
 
 public class TopSightContentTypeImpl implements TnefContentTypes {
    
    public TopSightContentTypeImpl() {
    }
    
    
    // ------ TnefContentTypes Interface Methods --------
    
    /**
     * Returns the MIME content type given a file extension. Eg: .txt or .gif
     * The default value is application/octet-stream
     *
     * @param ext file extentsion.
     */
    public String getContentTypeFromExtension(String ext) { 
        if (ext == null) {
            return "application/octet-stream";
        }
        return MimeTypeMap.getMimeType(ext.trim().toLowerCase());
    }        

    /**
     * Returns the MIME content type given a file name. Eg: hello.txt or image.gif
     * The default value is application/octet-stream
     *
     * @param name file name with extentsion.
     */
    public String getContentTypeFromFilename(String filename){
        //System.out.println("GET CT filename=" + filename);
        if (filename == null) {
            return "application/octet-stream";
        }
        int idx = filename.lastIndexOf(".");
        if (idx > 0) {
            String ext = filename.substring(idx + 1);
            return getContentTypeFromExtension(ext);
        }
        return getContentTypeFromExtension(filename);
    }               
 
 }    